@@ -23,7 +23,7 @@ using Gdk;
 using Mono.Unix;
 using System.Text;
 
-namespace gbrainy.Clients.Classical
+namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class AboutDialog : Gtk.AboutDialog
 	{
@@ -31,7 +31,16 @@ namespace gbrainy.Clients.Classical
 		{
 			StringBuilder license = new StringBuilder (256);
 			string [] authors = new string [] {
-				"Jordi Mas i Hernandez <jmas@softcatala.org>",
+				Catalog.GetString ("Software"),
+				"  Jordi Mas i Hernandez <jmas@softcatala.org>",
+				"",
+				Catalog.GetString ("Based on ideas by"),
+				"  Terry Stickels",
+				"  Jordi Mas i Hernandez",
+				"  Lewis Carroll",
+				("  " + Catalog.GetString ("MENSA works")),
+				"  mathforum.org",
+				"  Teun Spaans"
 			};
 
 			string [] artists = new string [] {
@@ -39,8 +48,8 @@ namespace gbrainy.Clients.Classical
 				"Carme Cabal Sard\u00e0",
 				"Jordi Mas i Hernandez",
 				"Felipe Menegaz",
+				"John Cliff",
 				"Openclipart.org",
-
 			};
 
 			string [] documenters = new string [] {
@@ -64,12 +73,13 @@ namespace gbrainy.Clients.Classical
 			Documenters = documenters;
 			Logo = LoadFromAssembly ("gbrainy.svg");
 
-			Copyright = Defines.COPYRIGHT + "\n";
-			Copyright += Catalog.GetString ("Based on ideas by Terry Stickels, MENSA books and Jordi Mas.");
+			Copyright = Defines.COPYRIGHT;
 
 			Comments = Catalog.GetString ("A brain teaser game for fun and to keep your brain trained.");
-			Website = "http://live.gnome.org/gbrainy";
-			WebsiteLabel = Catalog.GetString ("gbrainy web site");
+			Comments += "\n";
+			Comments += Catalog.GetString ("gbrainy project web site" + ":" + "http://live.gnome.org/gbrainy");
+			Website = Defines.WEB_SITE;
+			WebsiteLabel = String.Format (Catalog.GetString ("You can also play on-line at {0}"), Defines.WEB_SITE);
 			TranslatorCredits = translators;
 			Artists = artists;
 			IconName = null;
