@@ -24,7 +24,7 @@ using Mono.Unix;
 using gbrainy.Core.Main;
 using gbrainy.Core.Views;
 
-namespace gbrainy.Clients.Classical
+namespace gbrainy.Clients.Classical.Dialogs
 {
 	public class PlayerHistoryDialog : BuilderDialog
 	{
@@ -40,22 +40,24 @@ namespace gbrainy.Clients.Classical
 
 		public PlayerHistoryDialog (PlayerHistory history) : base ("PlayerHistoryDialog.ui", "playerhistory")
 		{
-			string label;
+			string intro, built;
 
-			label = Catalog.GetString ("The graph below shows the player's game score evolution. ");
+			intro = Catalog.GetString ("The graph below shows the player's game score evolution.");
 
 			if (history.Games.Count < 2)
 			{
-				label += Catalog.GetString ("You need more than one game session recorded to see the score evolution.");
+				built = Catalog.GetString ("You need more than one game session recorded to see the score evolution.");
 			}
 			else 
 			{
-				label +=  Catalog.GetPluralString ("It is built using the results of {0} recorded game session.",
+				built =  String.Format (Catalog.GetPluralString ("It is built using the results of {0} recorded game session.",
 					"It is built using the results of the last {0} recorded game sessions.",
-					history.Games.Count);
+					history.Games.Count),
+					history.Games.Count);	
 			}
 
-			label_playerhistory.Text = String.Format (label, history.Games.Count);
+			// Translators: "The graph below" +  "It is built using" sentences
+			label_playerhistory.Text = String.Format (Catalog.GetString ("{0} {1}"), intro, built);
 
 			drawing_area = new CairoPreview (history);
 			history_preview.Add (drawing_area);
@@ -63,8 +65,8 @@ namespace gbrainy.Clients.Classical
 
 	 		checkbutton_total.Label = Catalog.GetString ("Total");
 	 		checkbutton_logic.Label = GameTypesDescription.GetLocalized (GameTypes.LogicPuzzle);
-	 		checkbutton_calculation.Label = GameTypesDescription.GetLocalized (GameTypes.MathTrainer);
-	 		checkbutton_memory.Label = GameTypesDescription.GetLocalized (GameTypes.MemoryTrainer);
+	 		checkbutton_calculation.Label = GameTypesDescription.GetLocalized (GameTypes.Calculation);
+	 		checkbutton_memory.Label = GameTypesDescription.GetLocalized (GameTypes.Memory);
 	 		checkbutton_verbal.Label = GameTypesDescription.GetLocalized (GameTypes.VerbalAnalogy);
 
 	 		checkbutton_total.Active = checkbutton_memory.Active = checkbutton_logic.Active = checkbutton_calculation.Active = checkbutton_verbal.Active = true;
@@ -100,7 +102,7 @@ namespace gbrainy.Clients.Classical
 			drawing_area.QueueDraw ();
 		}
 
-		public class CairoPreview : DrawingArea
+		class CairoPreview : DrawingArea
 		{
 			PlayerHistoryView view;
 
