@@ -26,6 +26,8 @@ using Gdk;
 
 using gbrainy.Core.Main;
 using gbrainy.Core.Platform;
+using gbrainy.Clients.Classical.Dialogs;
+using gbrainy.Clients.Classical.Widgets;
 
 #if MONO_ADDINS
 using Mono.Addins;
@@ -415,12 +417,12 @@ namespace gbrainy.Clients.Classical
 			else
 				logic_menuitem.Sensitive = logic_tbbutton.Sensitive = false;
 
-			if (playing == false && ((available & GameTypes.MemoryTrainer) == GameTypes.MemoryTrainer))
+			if (playing == false && ((available & GameTypes.Calculation) == GameTypes.Calculation))
 				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = true;
 			else
 				memory_menuitem.Sensitive = memory_tbbutton.Sensitive = false;
 
-			if (playing == false && ((available & GameTypes.MathTrainer) == GameTypes.MathTrainer))
+			if (playing == false && ((available & GameTypes.Calculation) == GameTypes.Calculation))
 				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = true;
 			else
 				calculation_menuitem.Sensitive = calculation_tbbutton.Sensitive = false;
@@ -465,7 +467,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnMenuAbout (object sender, EventArgs args)
 		{
-			AboutDialog about = new AboutDialog ();
+			Dialogs.AboutDialog about = new Dialogs.AboutDialog ();
 			about.Run ();
 		}
 
@@ -549,7 +551,7 @@ namespace gbrainy.Clients.Classical
 
 		void OnMathOnly (object sender, EventArgs args)
 		{
-			OnNewGame (GameSession.Types.CalculationTrainers);
+			OnNewGame (GameSession.Types.Calculation);
 		}
 
 		void OnVerbalOnly (object sender, EventArgs args)
@@ -559,7 +561,16 @@ namespace gbrainy.Clients.Classical
 
 		void OnMemoryOnly (object sender, EventArgs args)
 		{
-			OnNewGame (GameSession.Types.MemoryTrainers);
+			OnNewGame (GameSession.Types.Memory);
+		}
+
+		void OnPdfExport (object sender, EventArgs args)
+		{
+			PdfExportDialog pdf;
+			
+			pdf = new PdfExportDialog ();
+			pdf.Run ();
+			pdf.Destroy (); 
 		}
 
 		void OnPreferences (object sender, EventArgs args)
