@@ -62,6 +62,7 @@ namespace gbrainy.Core.Main
 
 		protected Game ()
 		{
+			containers = new List <Toolkit.Container> ();
 			difficulty = GameDifficulty.Medium;
 		}
 
@@ -129,7 +130,6 @@ namespace gbrainy.Core.Main
 		{
 			random = new Random ();
 			default_color = new Cairo.Color (0, 0, 0);
-			containers = new List <Toolkit.Container> ();
 			Initialize ();
 		}
 
@@ -152,8 +152,9 @@ namespace gbrainy.Core.Main
 
 				if (String.IsNullOrEmpty (Rationale))
 					return str;
-
-				return str += " " + Rationale;
+				
+				// Translators: answer + rationale of the answer
+				return String.Format (Catalog.GetString ("{0} {1}"), str, Rationale);
 			}
 		}
 
@@ -344,6 +345,8 @@ namespace gbrainy.Core.Main
 			gr.DrawBackground ();
 			gr.Color = default_color;
 			gr.LineWidth = LineWidth;
+			// Not all Cairo surfaces have a default font size (like PDF)
+			gr.SetPangoNormalFontSize ();
 		}
 
 		public virtual void Draw (CairoContextEx gr, int width, int height, bool rtl)
