@@ -33,11 +33,11 @@ namespace gbrainy.Core.Main
 		{	
 			None			= 0,
 			LogicPuzzles		= 2,
-			MemoryTrainers		= 4,
-			CalculationTrainers	= 8,
+			Memory			= 4,
+			Calculation		= 8,
 			VerbalAnalogies		= 16,
 			Custom			= 32,
-			AllGames		= MemoryTrainers | CalculationTrainers | LogicPuzzles | VerbalAnalogies
+			AllGames		= Memory | Calculation | LogicPuzzles | VerbalAnalogies
 		}
 
 		public enum SessionStatus
@@ -172,14 +172,20 @@ namespace gbrainy.Core.Main
 				if (Status == SessionStatus.NotPlaying)
 					return string.Empty;
 
-				String text;
-				text = String.Format (Catalog.GetString ("Games played: {0} (Score: {1})"), history.GamesPlayed, history.TotalScore);
-				text += String.Format (Catalog.GetString (" - Time: {0}"), current_time);
+				string played, time, game;
 
-				if (CurrentGame != null)
-	 				text += " " + String.Format (Catalog.GetString ("- Game: {0}"), CurrentGame.Name);
-	
-				return text;
+				played = String.Format (Catalog.GetString ("Games played: {0} (Score: {1})"), history.GamesPlayed, history.TotalScore);
+				time = String.Format (Catalog.GetString ("Time: {0}"), current_time);
+
+				if (CurrentGame != null) {
+					// Translators: {0} is the name of the game
+	 				game = String.Format (Catalog.GetString ("Game: {0}"), CurrentGame.Name);
+					// Translators: text in the status bar: games played - time - game name
+					return String.Format (Catalog.GetString ("{0} - {1} - {2}"), played, time, game);
+				} else {
+					// Translators: text in the status bar: games played - time
+					return String.Format (Catalog.GetString ("{0} - {1}"), played, time);
+				}	
 			}
 		}
 
@@ -189,15 +195,16 @@ namespace gbrainy.Core.Main
 				string s;
 
 				if (history.GamesPlayed >= 10) {
-					if (history.TotalScore >= 70)
-						s = String.Format (Catalog.GetString ("Outstanding results"));
-					else if (history.TotalScore >= 50)
-						s = String.Format (Catalog.GetString ("Excellent results"));
-					else if (history.TotalScore >= 30)
-						s = String.Format (Catalog.GetString ("Good results"));
-					else if (history.TotalScore >= 20)
-						s = String.Format (Catalog.GetString ("Poor results"));
-					else s = String.Format (Catalog.GetString ("Disappointing results"));
+					int percentage_won = (int) (100 * history.GamesWon / history.GamesPlayed);
+					if (percentage_won >= 90)
+						s = Catalog.GetString ("Outstanding results");
+					else if (percentage_won >= 70)
+						s = Catalog.GetString ("Excellent results");
+					else if (percentage_won >= 50)
+						s = Catalog.GetString ("Good results");
+					else if (percentage_won >= 30)
+						s = Catalog.GetString ("Poor results");
+					else s = Catalog.GetString ("Disappointing results");
 				} else
 					s = string.Empty;
 	
@@ -239,20 +246,27 @@ namespace gbrainy.Core.Main
 		}
 
 		public void NextGame ()
-		{	
-			if (CurrentGame != null)
-				CurrentGame.Finish ();
+		{
+			try
+			{
+				if (CurrentGame != null)
+					CurrentGame.Finish ();
 
-			history.GamesPlayed++;
-			CurrentGame = game_manager.GetPuzzle ();
-			CurrentGame.SynchronizingObject = SynchronizingObject;
-			CurrentGame.DrawRequest += GameDrawRequest;
-			CurrentGame.UpdateUIElement += GameUpdateUIElement;
+				history.GamesPlayed++;
+				CurrentGame = game_manager.GetPuzzle ();
+				CurrentGame.SynchronizingObject = SynchronizingObject;
+				CurrentGame.DrawRequest += GameDrawRequest;
+				CurrentGame.UpdateUIElement += GameUpdateUIElement;
 
-			CurrentGame.Begin ();
+				CurrentGame.Begin ();
 
-			CurrentGame.GameTime = TimeSpan.Zero;
-			Status = SessionStatus.Playing;
+				CurrentGame.GameTime = TimeSpan.Zero;
+				Status = SessionStatus.Playing;
+			}
+			catch (Exception e)
+			{
+				Console.WriteLine ("GameSession.NextGame {0}", e);
+			}
 		}
 
 		public void Pause ()
