@@ -162,6 +162,7 @@ namespace gbrainy.Core.Views
 			y += 0.36;
 			gr.MoveTo (x, y);
 			gr.SetPangoFontSize (smaller_font);
+			// Translators: translated string should not be longer that the English original (space restriction on the UI)
 			gr.ShowPangoText (Catalog.GetString ("For details on how gbrainy's scoring works refer to the help."));
 
 			y += 0.07;
@@ -214,13 +215,13 @@ namespace gbrainy.Core.Views
 							records[i].NewScore,
 							records[i].PreviousScore);
 						break;
-					case GameTypes.MathTrainer:
+					case GameTypes.Calculation:
 						s = String.Format (Catalog.
 							GetString ("By scoring {0} in calculation games you have established a new personal record. Your previous record was {1}."),
 							records[i].NewScore,
 							records[i].PreviousScore);
 						break;
-					case GameTypes.MemoryTrainer:
+					case GameTypes.Memory:
 						s = String.Format (Catalog.
 							GetString ("By scoring {0} in memory games you have established a new personal record. Your previous record was {1}."),
 							records[i].NewScore,
