@@ -61,11 +61,11 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override GameTypes Type {
-			get { return GameTypes.MathTrainer;}
+			get { return GameTypes.Calculation;}
 		}
 
 		public override string Question {
-			get {return String.Format (Catalog.GetString ("What is the result of the given operation? Answer using either a fraction or a number."));} 
+			get {return Catalog.GetString ("What is the result of the given operation? Answer using either a fraction or a number.");} 
 		}
 
 		private int Factor {
