@@ -38,15 +38,18 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override GameTypes Type {
-			get { return GameTypes.MathTrainer;}
+			get { return GameTypes.Calculation;}
 		}
 
 		public override string Question {
-			get {return Catalog.GetString ("Which of the possible divisors is the greatest that divides all numbers?");} 
+			get { return String.Format (Catalog.GetString (
+				"Which of the possible divisors is the greatest that divides all numbers? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3));
+			}
 		}
 
 		protected override void Initialize ()
-		{	
+		{
 			bool found;
 			int n, m;
 			int []mult = new int [3];
@@ -69,23 +72,23 @@ namespace gbrainy.Games.Calculation
 			numbers = new int [num_answ_ques];
 			answers = new int [num_answ_ques];
 
-			// Common multiplayers for all numbers
+			// Common multipliers for all numbers
 			for (m = 0; m < mult.Length; m++) {
 				mult[m] = GetMultiplier (mult);
 			}
-		
+
 			n = 0;
 			while (n < numbers.Length) {
 				numbers [n] = 4 + random.Next (5);
 				for (int i = 1; i < 5; i++) {
 					numbers [n] =  numbers [n]  * (1 + random.Next (10));
 				}
-		
+
 				for (m = 0; m < mult.Length; m++) {
 					numbers[n] = numbers [n] * mult[m];
 				}
-			
-				if (numbers[n] > max_num || numbers[n] < 50) 
+
+				if (numbers[n] > max_num || numbers[n] < 50)
 					continue;
 
 				found = false;
@@ -93,42 +96,48 @@ namespace gbrainy.Games.Calculation
 					if (numbers[i]  == numbers [n]) {
 						found = true;
 						break;
-					}				
+					}
 				}
-				if (found == false)
+				if (found == false) {
 					n++;
-			}
-
-			for (n = 0; n < answers.Length; n++) {
-				answers[n] = GetUniqueAnswer (mult, answers);
-			}
-
-			n = 0;
-			int answer = 0;
-			for (int a = 0; a < answers.Length; a++)
-			{
-				for (n = 0; n < answers.Length; n++)
-				{
-					if ((double)numbers[n] / (double)answers[a] !=  Math.Abs (numbers[n] / answers[a]))
-						break;								
 				}
-			
-				if (n == answers.Length && answers[a] > answer)
+			}
+
+			int answer = 0;
+			// Avoid generating a set of answers in which none matches the condition
+			while (answer == 0)
+			{
+				// Build a list of answers
+				for (n = 0; n < answers.Length; n++) {
+					answers[n] = GetUniqueAnswer (mult, answers);
+				}
+
+				n = 0;
+				for (int a = 0; a < answers.Length; a++)
 				{
-					answer = answers[a];
-					answer_idx = a;
+					for (n = 0; n < answers.Length; n++)
+					{
+						if ((double)numbers[n] / (double)answers[a] !=  Math.Abs (numbers[n] / answers[a]))
+							break;
+					}
+
+					if (n == answers.Length && answers[a] > answer)
+					{
+						answer = answers[a];
+						answer_idx = a;
+					}
 				}
 			}
 
 			right_answer = answer.ToString ();
 
 			// Drawing objects
-			Container container = new Container (DrawAreaX + 0.2, DrawAreaY + 0.25, 0.6, answers.Length * 0.15);
+			Container container = new Container (DrawAreaX + 0.2, DrawAreaY + 0.25, 0.4, answers.Length * 0.15);
 			AddWidget (container);
-	
+
 			for (int i = 0; i < answers.Length; i++)
 			{
-				DrawableArea drawable_area = new DrawableArea (0.5, 0.1);
+				DrawableArea drawable_area = new DrawableArea (0.3, 0.1);
 				drawable_area.X = DrawAreaX + 0.23;
 				drawable_area.Y = DrawAreaY + 0.27 + i * 0.15;
 				container.AddChild (drawable_area);
@@ -138,8 +147,8 @@ namespace gbrainy.Games.Calculation
 				drawable_area.DrawEventHandler += delegate (object sender, DrawEventArgs e)
 				{
 					int d = (int) e.Data;
-					e.Context.SetPangoLargeFontSize ();	
-					e.Context.MoveTo (0.05, 0.02);
+					e.Context.SetPangoLargeFontSize ();
+					e.Context.MoveTo (0.07, 0.02);
 					e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (d),
 						answers[d].ToString ()));
 				};
@@ -160,7 +169,7 @@ namespace gbrainy.Games.Calculation
 				case 1:
 					answer = mult[0] * mult[1];
 					break;
-				case 2:	
+				case 2:
 					answer = mult[0] * mult[2];
 					break;
 				case 3:
@@ -185,7 +194,7 @@ namespace gbrainy.Games.Calculation
 				if (n == answers.Length)
 					found = true;
 			}
-	
+
 			return answer;
 		}
 
@@ -212,7 +221,7 @@ namespace gbrainy.Games.Calculation
 
 				}
 				for (n = 0; n < nums.Length; n++) {
-					if (nums[n] == rslt) 
+					if (nums[n] == rslt)
 						break;
 				}
 
@@ -224,13 +233,11 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
-		{	
+		{
 			double x = DrawAreaX, y = 0.05;
 
 			base.Draw (gr, area_width, area_height, rtl);
 
-			
-
 			gr.MoveTo (0.05, y);
 			gr.SetPangoLargeFontSize ();
 			gr.ShowPangoText (Catalog.GetString ("Numbers"));
@@ -243,7 +250,7 @@ namespace gbrainy.Games.Calculation
 				gr.Stroke ();
 				x += 0.17;
 			}
-		
+
 			y += 0.16;
 
 			gr.MoveTo (0.05, y);
@@ -251,11 +258,11 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override bool CheckAnswer (string answer)
-		{	
+		{
 			if (base.CheckAnswer (answer) == true)
 				return true;
 
-			if (String.Compare (answer, GetPossibleAnswer (answer_idx), true) == 0) 
+			if (String.Compare (answer, GetPossibleAnswer (answer_idx), true) == 0)
 				return true;
 
 			return false;
