@@ -38,7 +38,7 @@ namespace gbrainy.Games.Calculation
 		}
 
 		public override GameTypes Type {
-			get { return GameTypes.MathTrainer;}
+			get { return GameTypes.Calculation;}
 		}
 
 		public override string Question {
@@ -79,7 +79,7 @@ namespace gbrainy.Games.Calculation
 			options [options_next++] = correct;
 			options [options_next++] = percentage / 70d * num / den;
 			options [options_next++] = percentage / 120d * num / den;
-			options [options_next++] = percentage / 150d * num / den;;
+			options [options_next++] = percentage / 150d * num / den;
 
 			random_indices = new ArrayListIndicesRandom (options_cnt);
 			random_indices.Initialize ();
