@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using System;
 using Cairo;
 using Mono.Unix;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -41,7 +39,11 @@ namespace gbrainy.Games.Logic
 			get {return Catalog.GetString ("What percentage of the figure is colored?");} 
 		}
 
-		public override void Initialize ()
+		public override string AnswerCheckExpression {
+			get { return "[0-9]+";}
+		}
+
+		protected override void Initialize ()
 		{
 			int total = 0;
 
@@ -159,16 +161,5 @@ namespace gbrainy.Games.Logic
 
 			DrawSection (gr, x, y);
 		}
-
-		public override bool CheckAnswer (string answer)
-		{	
-			if (String.Compare (answer, right_answer, true) == 0) 
-				return true;
-
-			if (String.Compare (answer, right_answer + "%", true) == 0) 
-				return true;
-
-			return false;
-		}
 	}
 }
