@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -40,11 +38,9 @@ namespace gbrainy.Games.Logic
 			get {return Catalog.GetString ("How many line segments in total are in the figures below? A line segment is a line between two points with no crossing lines.");}
 		}
 
-		public override string Answer {
-			get { 
-				string answer = base.Answer + " ";
-				answer += String.Format (Catalog.GetString ("There are {0} lines in the figure to the left and {1} in the figure to the right."), fig1, fig2);
-				return answer;
+		public override string Rationale {
+			get {
+				return String.Format (Catalog.GetString ("There are {0} lines in the figure to the left and {1} in the figure to the right."), fig1, fig2);
 			}
 		}
 
@@ -52,9 +48,9 @@ namespace gbrainy.Games.Logic
 			get { return Catalog.GetString ("It is an easy exercise if you systematically count the lines.");}
 		}
 
-		public override void Initialize ()
+		protected override void Initialize ()
 		{
-			if (CurrentDifficulty==Difficulty.Easy)
+			if (CurrentDifficulty==GameDifficulty.Easy)
 				type = 0;
 			else
 				type = random.Next (max_types);		
