@@ -32,7 +32,7 @@ namespace gbrainy.Games.Logic
 		ArrayListIndicesRandom random_indices;
 		const int num_options = 4;
 
-		internal struct Predicate
+		struct Predicate
 		{
 			internal string question;
 			internal string [] options;
@@ -42,7 +42,7 @@ namespace gbrainy.Games.Logic
 			{
 				this.question = question;
 				this.answer_index = answer_index;
-				
+
 				options = new string [num_options];
 				options[0] = op1;
 				options[1] = op2;
@@ -51,9 +51,9 @@ namespace gbrainy.Games.Logic
 			}
 		};
 
-		Predicate [] predicates = 
+		Predicate [] predicates =
 		{
-			new Predicate (String.Format (Catalog.GetString ("If all painters are artists and some citizens of Barcelona are artists. Which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
+			new Predicate (String.Format (Catalog.GetString ("If all painters are artists and some citizens of Barcelona are artists. Which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
 					GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
 				Catalog.GetString ("Some citizens of Barcelona are painters"),
 				Catalog.GetString ("All citizens of Barcelona are painters"),
@@ -61,7 +61,7 @@ namespace gbrainy.Games.Logic
 				Catalog.GetString ("None of the other options"),
 				3),
 
-			new Predicate (String.Format (Catalog.GetString ("If no ill artist is happy and some artists are happy. Which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
+			new Predicate (String.Format (Catalog.GetString ("If no ill artist is happy and some artists are happy. Which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
 					GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
 				Catalog.GetString ("Some artist are not ill"),
 				Catalog.GetString ("Some painters are not artists"),
@@ -69,7 +69,7 @@ namespace gbrainy.Games.Logic
 				Catalog.GetString ("None of the other options"),
 				0),
 
-			new Predicate (String.Format (Catalog.GetString ("People that travel always buy a map. You are not going to travel. Which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
+			new Predicate (String.Format (Catalog.GetString ("People that travel always buy a map. You are not going to travel. Which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
 				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
 				Catalog.GetString ("You do not have any map"),
 				Catalog.GetString ("You do not buy a map"),
@@ -77,13 +77,53 @@ namespace gbrainy.Games.Logic
 				Catalog.GetString ("None of the other options"),
 				3),
 
-			new Predicate (String.Format (Catalog.GetString ("If you whistle if you are happy and you always smile when you whistle, which of the following sentences is correct? Answer {0}, {1}, {2} or {3}."),
+			new Predicate (String.Format (Catalog.GetString ("If you whistle if you are happy and you always smile when you whistle, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
 				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
 				Catalog.GetString ("You smile if you are happy"),
 				Catalog.GetString ("You are only happy if you whistle"),
 				Catalog.GetString ("You whistle if you are not happy"),
 				Catalog.GetString ("None of the other options"),
 				0),
+
+			new Predicate (String.Format (Catalog.GetString ("If your course is always honest and your course is always the best policy, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
+				Catalog.GetString ("Honesty is sometimes the best policy"),
+				Catalog.GetString ("Honesty is always the best policy"),
+				Catalog.GetString ("Honesty is not always the best policy"),
+				Catalog.GetString ("Some of the best policies are dishonest"),
+				0),
+
+			new Predicate (String.Format (Catalog.GetString ("If no old misers are cheerful and some old misers are thin, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
+				Catalog.GetString ("Some thin people are not cheerful"),
+				Catalog.GetString ("Thin people are not cheerful"),
+				Catalog.GetString ("Cheerful people are not thin"),
+				Catalog.GetString ("Some cheerful people are not thin"),
+				0),
+
+			new Predicate (String.Format (Catalog.GetString ("If all pigs are fat and nothing that is fed on barley-water is fat, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
+				Catalog.GetString ("All animals fed on barley-water are non pigs"),
+				Catalog.GetString ("No pigs are fed on barley-water"),
+				Catalog.GetString ("Pigs are not fed on barley-water"),
+				Catalog.GetString ("All the other options"),
+				3),
+
+			new Predicate (String.Format (Catalog.GetString ("If some pictures are first attempts and no first attempts are really good, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
+				Catalog.GetString ("Some bad pictures are not first attempts"),
+				Catalog.GetString ("Some pictures are not really good"),
+				Catalog.GetString ("All bad pictures are first attempts"),
+				Catalog.GetString ("All the others"),
+				1),
+
+			new Predicate (String.Format (Catalog.GetString ("If you have been out for a walk and you are feeling better, which of the following conclusions is correct? Answer {0}, {1}, {2} or {3}."),
+				GetPossibleAnswer (0), GetPossibleAnswer (1), GetPossibleAnswer (2), GetPossibleAnswer (3)),
+				Catalog.GetString ("To feel better, you must go out for a walk"),
+				Catalog.GetString ("If you go out for a walk, you will feel better"),
+				Catalog.GetString ("Some who go out for a walk feel better"),
+				Catalog.GetString ("No one feels better who does not go out for a walk"),
+				2),
 		};
 
 		public override string Name {
@@ -91,7 +131,7 @@ namespace gbrainy.Games.Logic
 		}
 
 		public override string Question {
-			get {return predicates[question].question;} 
+			get {return predicates[question].question;}
 		}
 
 		protected override void Initialize ()
@@ -115,14 +155,14 @@ namespace gbrainy.Games.Logic
 				}
 			}
 
-			Container container = new Container (DrawAreaX, DrawAreaX + 0.2, 0.8, 0.6);
+			Container container = new Container (DrawAreaX, DrawAreaY + 0.15, 0.8, 0.6);
 			AddWidget (container);
-	
+
 			for (int i = 0; i <  predicates[question].options.Length; i++)
 			{
-				DrawableArea drawable_area = new DrawableArea (0.8, 0.1);
+				DrawableArea drawable_area = new DrawableArea (0.8, 0.12);
 				drawable_area.X = DrawAreaX;
-				drawable_area.Y = DrawAreaY + 0.2 + i * 0.15;
+				drawable_area.Y = DrawAreaY + 0.15 + i * 0.18;
 				container.AddChild (drawable_area);
 				drawable_area.Data = i;
 				drawable_area.DataEx = GetPossibleAnswer (i);
@@ -131,11 +171,10 @@ namespace gbrainy.Games.Logic
 				{
 					int data = (int) e.Data;
 					int option = random_indices [data];
-					
+
 					e.Context.SetPangoNormalFontSize ();
-					e.Context.MoveTo (0.05, 0.02);
-					e.Context.ShowPangoText (String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (data),
-						predicates[question].options[option].ToString ()));
+					e.Context.DrawStringWithWrapping (0.05, 0.02, String.Format (Catalog.GetString ("{0}) {1}"), GetPossibleAnswer (data),
+						predicates[question].options[option].ToString ()), 0.8 - DrawAreaX);
 					e.Context.Stroke ();
 				};
 			}
@@ -146,7 +185,7 @@ namespace gbrainy.Games.Logic
 			base.Draw (gr, area_width, area_height, rtl);
 
 			gr.SetPangoLargeFontSize ();
-			gr.MoveTo (0.1, DrawAreaY + 0.05);
+			gr.MoveTo (0.1, DrawAreaY);
 			gr.ShowPangoText (Catalog.GetString ("Possible answers are:"));
 		}
 	}
