@@ -39,13 +39,14 @@ namespace gbrainy.Games.Logic
 
 		public override string Rationale {
 			get {
-				return Catalog.GetString ("The numbers in the figure reflect the different areas covered by each one of the sheets.");
+				// Translators: the translated version should not take more characters that the English original
+				return Catalog.GetString ("A full sized square of paper, a 3/4 of the whole size square of paper in the bottom right corner, another 3/4 square of paper in the top left corner and a 1/4 square of paper in the top left corner.");
 			}
 		}
 
 		protected override void Initialize ()
 		{
-			right_answer = "5";
+			right_answer = "4";
 		}
 
 		public override void Draw (CairoContextEx gr, int area_width, int area_height, bool rtl)
@@ -72,31 +73,6 @@ namespace gbrainy.Games.Logic
 			gr.MoveTo (x + 0.3, y);
 			gr.LineTo (x + 0.3, y + height - 0.1);  // Second vertical
 			gr.Stroke ();
-
-			if (DrawAnswer == false)
-				return;
-
-			gr.LineTo (x + 0.04, y + 0.06);
-			gr.ShowPangoText ("1");
-
-			gr.LineTo (x + 0.18, y + 0.06);
-			gr.ShowPangoText ("2");
-
-			gr.LineTo (x + 0.34, y + 0.06);
-			gr.ShowPangoText ("3");
-		
-			gr.LineTo (x + 0.04, y + 0.2);
-			gr.ShowPangoText ("2");
-
-			gr.LineTo (x + 0.18, y + 0.2);
-			gr.ShowPangoText ("4");
-
-			gr.LineTo (x + 0.34, y + 0.2);
-			gr.ShowPangoText ("5");
-
-			gr.LineTo (x + 0.04, y + 0.36);
-			gr.ShowPangoText ("3");
-
 		}
 	}
 }
