@@ -17,12 +17,10 @@
  * Boston, MA 02111-1307, USA.
  */
 
-using Cairo;
 using Mono.Unix;
 using System;
 
 using gbrainy.Core.Main;
-using gbrainy.Core.Libraries;
 
 namespace gbrainy.Games.Logic
 {
@@ -47,16 +45,17 @@ namespace gbrainy.Games.Logic
 				after, position_a, position_b, position_b));}
 		}
 
-
-		public override string Answer {
+		public override string Rationale {
 			get {
-				string answer = base.Answer + " ";
-				answer += String.Format (Catalog.GetString ("You have to calculate the hour from which the distance is the same for the given times, and then add the {0} hours to convert it to present time."), after);
-				return answer;
+				return String.Format (Catalog.GetString ("You have to calculate the hour from which the distance is the same for the given times, and then add the {0} hours to convert it to present time."), after);
 			}
 		}
 
-		public override void Initialize ()
+		public override GameAnswerCheckAttributes CheckAttributes {
+			get { return GameAnswerCheckAttributes.Trim | GameAnswerCheckAttributes.IgnoreCase | GameAnswerCheckAttributes.IgnoreSpaces; }
+		}
+
+		protected override void Initialize ()
 		{
 			int hour;
 			DateTime now;
@@ -85,28 +84,5 @@ namespace gbrainy.Games.Logic
 
 			gr.DrawTextCentered (0.5, DrawAreaY + 0.3 + figure_size, Catalog.GetString ("Sample clock"));
 		}
-
-		public override bool CheckAnswer (string answer)
-		{
-			string ans = string.Empty;
-			string user = string.Empty;
-
-			if (base.CheckAnswer (answer))
-				return true;
-
-			// Compare ignoring spaces then '1PM' is as valid as '1 PM'
-			for (int c = 0; c < answer.Length; c++)
-			{
-				if (Char.IsWhiteSpace (answer[c]) == false)
-					ans += answer[c];
-			}
-
-			for (int c = 0; c < right_answer.Length; c++)
-			{
-				if (Char.IsWhiteSpace (right_answer[c]) == false)
-					user += right_answer[c];
-			}
-			return (String.Compare (user, ans, true) == 0);
-		}
 	}
 }
