@@ -36,7 +36,7 @@ namespace gbrainy.Games.Memory
 		double rect_w, rect_h;
 		int question_pos, figures_active;
 
-		static internal class FigureType
+		static class FigureType
 		{
 			internal const int Triangle = 0;
 			internal const int Square = 1;
@@ -76,9 +76,6 @@ namespace gbrainy.Games.Memory
 
 			switch (CurrentDifficulty) {
 			case GameDifficulty.Easy:
-				figures_active = 4;
-				rows = columns = 2;
-				break;
 			case GameDifficulty.Medium:
 				figures_active = 6;
 				rows = 2;
